@@ -2,11 +2,15 @@ mod balance;
 mod event;
 mod expiration;
 mod pagination;
+mod parse_reply;
 mod payment;
 
 pub use pagination::{
-    calc_range_end_human, calc_range_start_human, calc_range_start_string, maybe_addr,
-    maybe_canonical,
+    calc_range_end, calc_range_start, calc_range_start_string, maybe_addr, maybe_canonical,
+};
+pub use parse_reply::{
+    parse_execute_response_data, parse_instantiate_response_data, parse_reply_execute_data,
+    parse_reply_instantiate_data, MsgExecuteContractResponse, MsgInstantiateContractResponse,
 };
 pub use payment::{may_pay, must_pay, nonpayable, one_coin, PaymentError};
 
